[![Build Status](https://travis-ci.com/rlworkgroup/metaworlds.svg?branch=master)](https://travis-ci.com/rlworkgroup/metaworlds)
[![Coverage Status](https://coveralls.io/repos/github/rlworkgroup/metaworlds/badge.svg?branch=skeleton)](https://coveralls.io/github/rlworkgroup/metaworlds?branch=skeleton)
[![Docs](https://readthedocs.org/projects/metaworlds/badge)](http://metaworlds.readthedocs.org/en/latest/)
[![License](https://img.shields.io/badge/license-MIT-blue.svg)](https://github.com/rlworkgroup/metaworlds/blob/master/LICENSE)

# metaworlds
Environments for bencharking meta-learning and multi-task learning
